%{?mingw_package_header}

%global name1 sqlite

%define realver %(echo %{version} | awk -F. '{printf "%d%02d%02d00", $1, $2, $3}')

# bcond default logic is nicely backwards...
%bcond_with tcl
%global tclversion 8.6

Name:           mingw-%{name1}
Version:        3.49.2
Release:        %mkrel 1
Summary:        MinGW Windows port of sqlite embeddable SQL database engine

License:        blessing
Group:          Development/Other
URL:            https://www.sqlite.org/
Source0:        https://www.sqlite.org/2025/%{name1}-src-%{realver}.zip

BuildArch:      noarch

# sqlite uses some home baked configure mechanism. Don't make unknown options fatal
Patch0:         sqlite-unknown-option.patch

BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  tcl

BuildRequires:  mingw32-dlfcn
BuildRequires:  mingw32-filesystem
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-binutils
BuildRequires:  mingw32-pdcurses
BuildRequires:  mingw32-readline
BuildRequires:  mingw32-termcap

BuildRequires:  mingw64-dlfcn
BuildRequires:  mingw64-filesystem
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-binutils
BuildRequires:  mingw64-pdcurses
BuildRequires:  mingw64-readline
BuildRequires:  mingw64-termcap


%if %{with tcl}
BuildRequires:  mingw32-tcl
BuildRequires:  mingw64-tcl
%endif


%description
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.


# Win32
%package -n mingw32-%{name1}
Summary:        MinGW Windows port of sqlite embeddable SQL database engine
Requires:       pkgconfig

%description -n mingw32-%{name1}
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.

%package -n mingw32-%{name1}-static
Summary:        Static version of MinGW Windows port of sqlite library
Requires:       mingw32-%{name1} = %{version}-%{release}
Group:          Development/Other

%description -n mingw32-%{name1}-static
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains static cross-compiled library

# Win64
%package -n mingw64-%{name1}
Summary:        MinGW Windows port of sqlite embeddable SQL database engine
Requires:       pkgconfig

%description -n mingw64-%{name1}
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host

This package contains cross-compiled libraries and development tools
for Windows.

%package -n mingw64-%{name1}-static
Summary:        Static version of MinGW Windows port of sqlite library
Requires:       mingw64-%{name1} = %{version}-%{release}
Group:          Development/Other

%description -n mingw64-%{name1}-static
SQLite is a C library that implements an SQL database engine. A large
subset of SQL92 is supported. A complete database is stored in a
single disk file. The API is designed for convenience and ease of use.
Applications that link against SQLite can enjoy the power and
flexibility of an SQL database without the administrative hassles of
supporting a separate database server.  Version 2 and version 3 binaries
are named to permit each to be installed on a single host.

This package contains static cross-compiled library.


%{?mingw_debug_package}


%prep
%autosetup -p1 -n %{name1}-src-%{realver}


%build
# add compile flags to enable rtree, fts3
export MINGW32_CFLAGS="%{mingw32_cflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 -DSQLITE_DISABLE_DIRSYNC=1 -DSQLITE_ENABLE_FTS3=3 -DSQLITE_ENABLE_RTREE=1 -fno-strict-aliasing"
export MINGW64_CFLAGS="%{mingw64_cflags} -DSQLITE_ENABLE_COLUMN_METADATA=1 -DSQLITE_DISABLE_DIRSYNC=1 -DSQLITE_ENABLE_FTS3=3 -DSQLITE_ENABLE_RTREE=1 -fno-strict-aliasing"

%mingw_configure %{!?with_tcl:--disable-tcl} --enable-all --enable-load-extension
%mingw_make_build


%install
%mingw_make_install

chmod 0644 %{buildroot}%{mingw32_libdir}/libsqlite3.dll.a
chmod 0644 %{buildroot}%{mingw64_libdir}/libsqlite3.dll.a

%if %{with tcl}
install -d -m755 %{buildroot}%{mingw32_datadir}/tcl%{tclversion}/sqlite3/
mv %{buildroot}%{_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl %{buildroot}%{mingw32_datadir}/tcl%{tclversion}/sqlite3/

install -d -m755 %{buildroot}%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
mv %{buildroot}%{_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl %{buildroot}%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
%endif

# Drop all .la files
find %{buildroot} -name "*.la" -delete

# Drop man pages
rm -rf %{buildroot}%{mingw32_mandir}
rm -rf %{buildroot}%{mingw64_mandir}

# Win32
%files -n mingw32-%{name1}
%doc README.md VERSION
%{mingw32_bindir}/sqlite3.exe
%{mingw32_bindir}/libsqlite3-0.dll
%{mingw32_libdir}/libsqlite3.dll.a
%{mingw32_includedir}/sqlite3.h
%{mingw32_includedir}/sqlite3ext.h
%{mingw32_libdir}/pkgconfig/sqlite3.pc
%if %{with tcl}
%{mingw32_datadir}/tcl%{tclversion}/sqlite3/
%{mingw32_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl
%endif

%files -n mingw32-%{name1}-static
%{mingw32_libdir}/libsqlite3.a

# Win64
%files -n mingw64-%{name1}
%doc README.md VERSION
%{mingw64_bindir}/sqlite3.exe
%{mingw64_bindir}/libsqlite3-0.dll
%{mingw64_libdir}/libsqlite3.dll.a
%{mingw64_includedir}/sqlite3.h
%{mingw64_includedir}/sqlite3ext.h
%{mingw64_libdir}/pkgconfig/sqlite3.pc
%if %{with tcl}
%{mingw64_datadir}/tcl%{tclversion}/sqlite3/
%{mingw64_datadir}/tcl%{tclversion}/sqlite3/pkgIndex.tcl
%endif

%files -n mingw64-%{name1}-static
%{mingw64_libdir}/libsqlite3.a




%changelog
* Fri May 30 2025 daviddavid <daviddavid> 3.49.2-1.mga10
+ Revision: 2187099
- new version: 3.49.2

* Sun Dec 29 2024 daviddavid <daviddavid> 3.47.2-1.mga10
+ Revision: 2131232
- new version: 3.47.2

* Thu Nov 21 2024 daviddavid <daviddavid> 3.47.0-1.mga10
+ Revision: 2118137
- new version: 3.47.0

* Tue Sep 24 2024 daviddavid <daviddavid> 3.46.1-1.mga10
+ Revision: 2101048
- new version: 3.46.1

* Mon Jun 17 2024 daviddavid <daviddavid> 3.46.0-1.mga10
+ Revision: 2074656
- new version: 3.46.0

* Mon May 06 2024 daviddavid <daviddavid> 3.45.3-1.mga10
+ Revision: 2062482
- new version: 3.45.3

* Wed Feb 07 2024 daviddavid <daviddavid> 3.45.1.0-1.mga10
+ Revision: 2038456
- new version: 3.45.1

* Sun Oct 29 2023 daviddavid <daviddavid> 3.43.2.0-2.mga10
+ Revision: 2002592
- new version: 3.43.2.0

* Mon Nov 21 2022 daviddavid <daviddavid> 3.36.0.0-2.mga9
+ Revision: 1909736
- new version 3.36.0.0

* Fri Mar 25 2022 umeabot <umeabot> 3.35.5.0-2.mga9
+ Revision: 1825503
- Mageia 9 Mass Rebuild

* Tue Apr 20 2021 daviddavid <daviddavid> 3.35.5.0-1.mga9
+ Revision: 1717311
- new version: 3.35.5.0

* Tue Apr 06 2021 daviddavid <daviddavid> 3.35.4.0-1.mga9
+ Revision: 1713803
- new version: 3.35.4.0

* Sat Mar 27 2021 daviddavid <daviddavid> 3.35.3.0-1.mga9
+ Revision: 1710828
- new version: 3.35.3.0

* Sun Mar 21 2021 daviddavid <daviddavid> 3.35.2.0-1.mga9
+ Revision: 1706536
- new version: 3.35.2.0

* Wed Mar 17 2021 daviddavid <daviddavid> 3.35.1.0-1.mga9
+ Revision: 1704020
- new version: 3.35.1.0

* Sun Feb 28 2021 daviddavid <daviddavid> 3.34.1.0-1.mga9
+ Revision: 1693305
- new version: 3.34.1.0

* Tue Dec 08 2020 daviddavid <daviddavid> 3.34.0.0-1.mga8
+ Revision: 1654732
- new version: 3.34.0.0

* Sat Sep 26 2020 tv <tv> 3.33.0.0-2.mga8
+ Revision: 1630278
- rebuild for new mingw stack

* Wed Aug 19 2020 daviddavid <daviddavid> 3.33.0.0-1.mga8
+ Revision: 1615616
- new version: 3.33.0.0

* Fri Jun 19 2020 daviddavid <daviddavid> 3.32.3.0-1.mga8
+ Revision: 1596737
- new version: 3.32.3.0

* Sun Jun 07 2020 daviddavid <daviddavid> 3.32.2.0-1.mga8
+ Revision: 1590835
- new version: 3.32.2.0

* Wed May 27 2020 daviddavid <daviddavid> 3.32.1.0-1.mga8
+ Revision: 1588147
- new version: 3.32.1.0

* Sun May 24 2020 daviddavid <daviddavid> 3.32.0.0-1.mga8
+ Revision: 1587229
- new version: 3.32.0.0

* Thu Feb 20 2020 umeabot <umeabot> 3.31.1.0-2.mga8
+ Revision: 1545292
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 3.31.1.0-1.mga8
+ Revision: 1484345
- new version: 3.31.1.0

* Thu Jan 23 2020 daviddavid <daviddavid> 3.31.0.0-2.mga8
+ Revision: 1482513
- new version: 3.31.0.0

* Tue Jan 07 2020 daviddavid <daviddavid> 3.30.1.0-2.mga8
+ Revision: 1477101
- rebuild for new mingw-readline 8.0

* Fri Oct 11 2019 daviddavid <daviddavid> 3.30.1.0-1.mga8
+ Revision: 1451999
- new version: 3.30.1.0

* Thu Jul 11 2019 daviddavid <daviddavid> 3.29.0.0-1.mga8
+ Revision: 1420006
- new version: 3.29.0.0

* Wed Apr 17 2019 daviddavid <daviddavid> 3.28.0.0-1.mga7
+ Revision: 1391961
- new version: 3.28.0.0

* Tue Feb 26 2019 daviddavid <daviddavid> 3.27.2.0-1.mga7
+ Revision: 1370202
- new version: 3.27.2.0

* Fri Feb 08 2019 daviddavid <daviddavid> 3.27.1.0-1.mga7
+ Revision: 1364314
- new version: 3.27.1.0

* Fri Feb 08 2019 daviddavid <daviddavid> 3.27.0.0-1.mga7
+ Revision: 1364123
- new version: 3.27.0.0

* Thu Feb 07 2019 daviddavid <daviddavid> 3.26.0.0-1.mga7
+ Revision: 1364048
- new version: 3.26.0.0

* Thu Sep 20 2018 umeabot <umeabot> 3.24.0.0-2.mga7
+ Revision: 1279933
- Mageia 7 Mass Rebuild

* Fri Jun 15 2018 daviddavid <daviddavid> 3.24.0.0-1.mga7
+ Revision: 1237075
- new version: 3.24.0.0

* Wed May 11 2016 tv <tv> 3.12.2.0-6.mga6
+ Revision: 1012805
- new release

* Thu Feb 04 2016 umeabot <umeabot> 3.7.17-6.mga6
+ Revision: 934560
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.7.17-5.mga5
+ Revision: 743471
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.7.17-4.mga5
+ Revision: 682513
- Mageia 5 Mass Rebuild

* Sun Oct 27 2013 neoclust <neoclust> 3.7.17-3.mga4
+ Revision: 547472
- imported package mingw-sqlite


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.17-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Jun 15 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.17-2
- Rebuild to resolve InterlockedCompareExchange regression in mingw32 libraries

* Sun Jun  2 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.17-1
- update to 3.7.17

* Sun May 12 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.16.2-2
- Don't try to link against pthreads even if it is available on win32
  (sqlite uses the native win32 threading API already)

* Mon May  6 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.16.2-1
- update to 3.7.16.2

* Sun Mar 24 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.16-1
- Update to 3.7.16

* Sun Mar  3 2013 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.15.2-1
- Update to 3.7.15.2

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.14.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Dec  6 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.14.1-1
- Update to 3.7.14.1
- Dropped all patches which are not needed for the mingw target
- There's no need to re-run the autotools any more

* Tue Dec  4 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.13-1
- update to 3.7.13

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sun Apr 22 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.9-6
- Add BR: mingw64-pdcurses

* Sat Mar 10 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.9-5
- Added win64 support

* Fri Mar 09 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.9-4
- Dropped .la files

* Tue Mar 06 2012 Kalev Lember <kalevlember@gmail.com> - 3.7.9-3
- Renamed the source package to mingw-sqlite (#800450)
- Modernize the spec file
- Use mingw macros without leading underscore

* Mon Feb 27 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 3.7.9-2
- Rebuild against the mingw-w64 toolchain

* Mon Jan 16 2012 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.9-1
- update to 3.7.9

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Sat Dec 24 2011 Ivan Romanov <drizt@land.ru> - 3.7.5-2
- static subpackage

* Sun Feb 13 2011 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.5-1
- update to 3.7.5

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec  6 2010 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.7.3-1
- update to 3.7.3

* Sun Jan 31 2010 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.22-1
- update to 3.6.22

* Sun Dec  6 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.20-1
- update to 3.6.20

* Sun Sep 20 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.17-1
- update to 3.6.17

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.14.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jun 23 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.14.2-1
- update to 3.6.14.2
- add debuginfo packages

* Thu Apr 23 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.12-4
- fix CFLAGS setting

* Thu Apr 23 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.12-3
- use Erik van Pienbroek way to add to CFLAGS

* Thu Apr 23 2009 Thomas Sailer <t.sailer@alumni.ethz.ch> - 3.6.12-2
- BR tclsh; the build process without tclsh and with extensions
  enabled is broken

* Thu Apr 23 2009 Thomas Sailer <t.sailer@alumni.ee.ethz.ch> - 3.6.12-1
- update to 3.6.12 to match native
- enable rtree, fts3

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.6.6.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Feb 20 2009 Richard W.M. Jones <rjones@redhat.com> - 3.6.6.2-2
- Rebuild for mingw32-gcc 4.4

* Tue Dec 16 2008 Richard Jones <rjones@redhat.com> - 3.6.6.2-1
- New upstream release (to match Fedora native), 3.6.6.2.
- Replace patches with ones from native.
- Rebase -no-undefined patch.
- Remove spurious +x permissions on libsqlite3.dll.a.
- Requires pkgconfig.

* Sat Nov 22 2008 Richard Jones <rjones@redhat.com> - 3.5.9-3
- Rebuild against new readline.

* Fri Oct 31 2008 Richard Jones <rjones@redhat.com> - 3.5.9-2
- Rebuild against latest termcap.

* Thu Sep 25 2008 Richard Jones <rjones@redhat.com> - 3.5.9-1
- Initial RPM release.
